Command Line Interface
======================
ols_client automatically installs the command :code:`ols_client`. See
:code:`ols_client --help` for usage details.

.. click:: ols_client.cli:main
   :prog: ols_client
   :show-nested:
